---
title: All Notebooks
sidebarTitle: All Notebooks
mode: "wide"
---

{/* DELETE-ME-WHILE-BUILDING-MKDOCS-START */}

import { GalleryPage } from '/snippets/components/GalleryPage.mdx';
import { ClientSideComponent } from "/snippets/components/ClientSideComponent.mdx";
import { notebooksMetadata } from "/snippets/data/NotebooksMetadata.mdx";

{/* DELETE-ME-WHILE-BUILDING-MKDOCS-END */}

This page contains a collection of notebooks that demonstrate how to use
AG2. The notebooks are tagged with the topics they cover.
For example, a notebook that demonstrates how to use function calling will
be tagged with `tool/function`.

{/* DELETE-ME-WHILE-BUILDING-MKDOCS-START */}

<ClientSideComponent Component={GalleryPage} componentProps={{galleryItems: notebooksMetadata, target: "_self", allowDefaultImage: false}} />

{/* DELETE-ME-WHILE-BUILDING-MKDOCS-END */}

{/* DELETE-ME-WHILE-BUILDING-MINTLIFY-START */}

{{ render_gallery(gallery_items) }}

{/* DELETE-ME-WHILE-BUILDING-MINTLIFY-END */}
